
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef demo_MSG_LIB_H
#define demo_MSG_LIB_H

#include "portLib.h"
#include "csLib.h"
#include "posterLib.h"
 
#include "demoType.h"

#define TIME_WAIT_REPLY           /*2000*/ 0
 



/*----------- Tailles des messages et boites aux lettres  ----------*/

/* Taille du buffer utilise dans la bal pour un mesage de taille size
 * (cf servMbox pour UNIX et h2rgnLib pour VXWORKS )
 */


#define BUF_SIZE(size) \
   (size + 4 - (size & 3) + sizeof(LETTER_HDR) + 8)

/**
 ** Boite aux lettres reception requetes 
 **/
#define  DEMO_MBOX_NAME                  genomInstanceName("demo")

#define  DEMO_MAX_RQST_SIZE              8

#define  DEMO_MBOX_RQST_SIZE       \
 (BUF_SIZE(DEMO_MAX_RQST_SIZE) * SERV_NMAX_RQST_ID)

/** 
 ** Taille max repliques (serveur)
 **/
#define  DEMO_MAX_INTERMED_REPLY_SIZE   (sizeof(int))

#define  DEMO_MAX_REPLY_SIZE             8

/** 
 ** Taille bal clients pour reception repliques 
 **/
#define  DEMO_CLIENT_MBOX_REPLY_SIZE   \
((BUF_SIZE(DEMO_MAX_REPLY_SIZE) \
   + BUF_SIZE(DEMO_MAX_INTERMED_REPLY_SIZE)) \
 * CLIENT_NMAX_RQST_ID)

/*-------------------------- Liste des requetes  -------------------------*/

#define DEMO_SETSPEED_RQST 0
#define DEMO_GETSPEED_RQST 1
#define DEMO_STOP_RQST 2
#define DEMO_MOVEDISTANCE_RQST 3
#define DEMO_GOTOPOSITION_RQST 4
#define DEMO_MONITOR_RQST 5
#define DEMO_ABORT_RQST 6


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif

STATUS demoClientInit (CLIENT_ID *pClientId);

STATUS demoClientEnd (CLIENT_ID clientId);

int demoAbortRqstSend (CLIENT_ID clientId, 
			   int *pRqstId,
			   int *activity,
			   int replyTimeOut);

int demoAbortReplyRcv (CLIENT_ID clientId, 
			   int rqstId, 
			   int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			   int *bilan);

int demoAbortRqstAndRcv (CLIENT_ID clientId, 
			     int *activity,
			     int *bilan);




extern STATUS demoSetSpeedRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 DEMO_SPEED *(in_speedRef),
					 int replyTimeOut);

int demoSetSpeedReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int demoSetSpeedRqstAndRcv (CLIENT_ID clientId, 
				 DEMO_SPEED *(in_speedRef), 
				 
				 int *bilan);




extern STATUS demoGetSpeedRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int demoGetSpeedReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       DEMO_SPEED *(out_speedRef),
			       int *bilan);

int demoGetSpeedRqstAndRcv (CLIENT_ID clientId, 
				  
				 DEMO_SPEED *(out_speedRef),
				 int *bilan);




extern STATUS demoStopRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int demoStopReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int demoStopRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);




extern STATUS demoMoveDistanceRqstSend (CLIENT_ID clientId, int *pRqstId,
					 double *(in_distRef),
					 int replyTimeOut);

extern int demoMoveDistanceReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int demoMoveDistanceRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					double *(in_distRef), 
					
					int *activity, int *bilan);

extern int demoMoveDistanceRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					double *(in_distRef), 
					
					int *activity,
					int *bilan);




extern STATUS demoGotoPositionRqstSend (CLIENT_ID clientId, int *pRqstId,
					 double *(in_posRef),
					 int replyTimeOut);

extern int demoGotoPositionReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int demoGotoPositionRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					double *(in_posRef), 
					
					int *activity, int *bilan);

extern int demoGotoPositionRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					double *(in_posRef), 
					
					int *activity,
					int *bilan);




extern STATUS demoMonitorRqstSend (CLIENT_ID clientId, int *pRqstId,
					 double *(in_monitor),
					 int replyTimeOut);

extern int demoMonitorReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      double *(out_position),
				      int *activity, int *bilan);


extern int demoMonitorRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					double *(in_monitor), 
					double *(out_position),
					int *activity, int *bilan);

extern int demoMonitorRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					double *(in_monitor), 
					double *(out_position),
					int *activity,
					int *bilan);


#ifdef __cplusplus
}
#endif
#endif /* demo_MSG_LIB_H */

